#version 3.7;

#declare RAD = 4;  // radiosity quality settings 0 = out; 1 = acceptable; 4 = good
                
global_settings {
        #declare a_g = 2.2;
        assumed_gamma a_g
        max_trace_level 3
        noise_generator 2  
        #if(RAD > 0)
                radiosity {
                        pretrace_start 0.08
                        pretrace_end   0.04/RAD
                        count 60*RAD                
                        nearest_count min (20, RAD)      
                        error_bound 2/RAD
                        low_error_factor 0.5      
                        recursion_limit 1      
                        gray_threshold 0  
                        minimum_reuse 0.015 
                        brightness 1      
                        adc_bailout 0.005
                        normal on
                        media off
                        always_sample off
                }
        #end
}        

#include "stdinc.inc"

camera { 
        location <0,5,-10> 
        look_at <-0.08,0.335,0> 
        angle 26.5*image_width/image_height*0.75
        right x*image_width/image_height 
        up y 
        //focal_point <0,0.5,-0.5> aperture 0.5 blur_samples 50
} 

sky_sphere {
        pigment {
                image_map {
                        hdr "kitchen_probe2.hdr"
                        gamma 2.2
                        map_type 1
                        interpolate 2
                }
        }
        emission rgb 0.7
        rotate <0,15*frame_number,0>
}

// Ron Parker  metal "swirl" finish  http://news.povray.org/povray.general/message/%3C37ced7f7%40news.povray.org%3E/#%3C37ced7f7%40news.povray.org%3E

#declare Rings = 128;
                                      
#macro ScalesPigment (Map) 

#local Scale = 
pigment {
        wood 
        color_map {Map} 
        scale 2
} 

pigment_pattern { 
        wood 
        pigment_map {
                [1/sqrt (2)   Scale scale 0.5/sqrt (2)]
                [1/sqrt (2)   Scale translate 1 scale 0.5/sqrt (2)]
        } 
        scale sqrt (2) 
        rotate 90*x 
        warp {repeat z*0.5 flip z} 
        warp {repeat x*0.5 offset z*0.5}
}

#end

#declare MyMap =
color_map { 
        #declare i = 0; 
        #while (i <= 2*Rings-1) 
                [i/(2*Rings-1)   rgb mod (i,2)] 
                #declare i = i+1; 
        #end
}

#declare T1596 =
material {
	texture {
                pigment {color rgb <0.83,0.82,0.84>}
                normal {
                        ScalesPigment (MyMap)
                        1
                }
	        normal {
                        average
                        normal_map {
                                [1      bumps 
                                        0.1 
                                        scale 0.0001
                                ]
                                [1      ScalesPigment (MyMap)
                                        2
                                ]
                        }
                }
		finish {
			diffuse 0.125
			ambient 0
			specular 0.8
			roughness 0.02
			phong 0.5
			phong_size 80
			reflection {0, 0.6 metallic}
		}
        }
	interior {ior 2.5}
	scale 1
        rotate -90*y
}

plane { 
        y, -0.25
        material {T1596}           
}

// left
// Pores code by Tekno Frannansa  Porous Rock  http://news.povray.org/povray.binaries.images/message/%3C486e82e5%40news.povray.org%3E/#%3C486e82e5%40news.povray.org%3E
// Iron texture by Mark Slone  Innocent Shadow  http://www.irtc.org/ftp/pub/stills/2002-12-31/ishadow.zip       
// Rust texture by Phil Brewer  quincy  http://www.irtc.org/ftp/pub/stills/2006-08-31/quincy.zip

#declare sponge_pig =
pigment {
        #local Curve    = 0.125; 
        #local Omega    = 0.5;
        #local Lambda   = 2;
        #local Octaves  = 8;
        pigment_pattern {
                average
                pigment_map {
                        #local octave = 0;
                        #while (octave < Octaves)
                                [pow (Omega, octave)
                                        pigment_pattern {
                                                crackle 
                                                form <0.9,0,0>
                                                scale pow (Lambda, -octave)
                                                color_map {
                                                        [0      rgb 1]
                                                        [1      rgb 0]
                                                }
                                        }
                                        poly_wave 1/Curve
                                ]
                                #local octave = octave+1;
                        #end
                }
        }
        poly_wave Curve
        color_map {
                [0.6    rgb 1]
                [1      rgb 0]
        }
}

#local IronPigment =
pigment {
	wrinkles
	color_map {
		[0      rgb <0.1,0.1,0.1>]
		[0.7    rgb <0.15,0.15,0.15>]
		[1      rgb <0.2,0.2,0.2>]
	}
	scale 5
}

#local IronTexture =
texture {
	pigment {IronPigment}
	normal {
                granite 
                0.2
        }
	finish {
		ambient 0
		roughness 0.015
		specular 0.2
		diffuse 1.2
		brilliance 2
		reflection {0.1, 0.3 fresnel on}
	}
}

#local RustPigment =
pigment {
	granite
	color_map {
		[0      rgb <0.71*0.9,0.3,0.11*1.1>*0.8]  
		[0.4    rgb <0.21*0.9,0.1,0.03*1.1>*1.2]  
		[0.6    rgb <0.21*0.9,0.1,0.03*1.1>*1.2]  
		[1      rgb <0.47*0.9,0.05,0.01*1.1>*0.9] 
	}
	scale 0.5
	turbulence 1
}

#local RustTexture =
texture {
	pigment {RustPigment}
	normal {
                granite 
                1
                scale 0.02
        }
        finish {ambient 0 diffuse 1.05}
}

#local RustTexture2 =
texture {
	pigment {
                RustPigment 
                warp {turbulence 1 omega 0.6 lambda 4} 
                scale <0.5,1,0.5>
        }
	normal {
                granite
                1 
                scale 0.02 
                warp {turbulence 1 omega 0.6 lambda 4} 
                scale <0.5,1,0.5>
        }
        finish {ambient 0 diffuse 1.05}
}

#local RustyIronTexture =
texture {
	bozo
	texture_map {
		[0      RustTexture]
		[0.3    RustTexture] 
		[0.6    IronTexture] 
		[1      IronTexture]
	}
	warp {turbulence 1 omega 0.6 lambda 4}
	scale <0.5,1,0.5>
}

#declare rusted_metal_tex1 =
texture {
        average
        texture_map {
                [1      pigment {
	                	bozo
	                	frequency 2
	                	turbulence 0.4
	                	octaves 8 
                                lambda 1.5 
                                omega 0.8
	                	color_map {
	                		[0      rgb <87*1.2,71,45*0.8>/255]
	                		[0.6    rgb <86*1.2,45,1*0.8>/255]
	                		[1      rgb <50*1.2,21,2*0.8>/255]
	                	}
	                }
	                normal {
                                average
                                normal_map {
                                        [1      granite 
                                                1.4 
                                                turbulence 0.4 
                                                octaves 8 
                                                lambda 1.5 
                                                omega 0.8
                                        ]
                                        [1      pigment_pattern {sponge_pig} 
                                                8 
                                                accuracy 0.001 
                                                cubic_wave
                                                scale 31.25
                                        ]
                                }
                        }
	                finish {
                                ambient 0 
                                diffuse 0.6 
                                specular 0.05 
                                roughness 0.05
                        }
                        scale 0.032
                ]
                [0.1    RustTexture2]
        }
}

#declare rusted_metal_tex2 =
texture {
        average
        texture_map {
                [1      pigment {
	                	bozo
	                	frequency 2
	                	turbulence 0.4
	                	octaves 8 
                                lambda 1.5 
                                omega 0.8
	                	color_map {
	                		[0      rgb <87*1.2,71,45*0.8>/255]
	                		[0.6    rgb <86*1.2,45,1*0.8>/255]
	                		[1      rgb <50*1.2,21,2*0.8>/255]
	                	}
	                }
	                normal {
                                average
                                normal_map {
                                        [1      granite 
                                                1.4 
                                                turbulence 0.4 
                                                octaves 8 
                                                lambda 1.5 
                                                omega 0.8
                                        ]
                                        [1      pigment_pattern {sponge_pig} 
                                                4 
                                                accuracy 0.001 
                                                cubic_wave
                                                scale 12.5
                                        ]
                                }
                        }
	                finish {
                                ambient 0 
                                diffuse 0.6 
                                specular 0.05 
                                roughness 0.05
                        }
                        scale 0.08
                ]
                [0.1    RustTexture2]
        }
}

#declare T2076 =
material {
	texture {
                pigment_pattern {sponge_pig}
                texture_map {
		        [0.5    rusted_metal_tex1]
		        [0.9    rusted_metal_tex2]
                        [0.9    RustTexture2]
                        [0.97   RustTexture2]
                        [1      RustyIronTexture]
                }
        }
	interior {ior 1.5}
	scale 1
}

superellipsoid { 
        <0.25, 0.25>
        rotate y*15
        translate <-2.3,0.625,-0.8> 
        material {T2076}
}

// middle
// inspired by LightBeam  Rocks from outer space  http://news.povray.org/povray.binaries.images/message/%3C4013fcf5%40news.povray.org%3E/#%3C4013fcf5%40news.povray.org%3E

#declare T2046 =
material {
	texture {
                pigment {
                        agate
                        scale 0.5  
                        agate_turb 0.7
                        pigment_map {
                                [0      granite 
                                        scale 0.015
                                        color_map {
                                                [0      rgb 0.6]
                                                [1      rgb 0.4]
                                        }
                                ]
                                [0.2    bumps 
                                        scale 0.005
                                        color_map {
                                                [0      rgb 0.6]
                                                [1      rgb 0.4]
                                        }
                                ]
                                [0.5    average
                                        pigment_map {
                                                [1      agate 
                                                        scale 0.5 
                                                        agate_turb 0.7
                                                        color_map {
                                                                [0      rgb 0.3]
                                                                [1      rgb 0.7]
                                                        }
                                                ]
                                                [1      granite 
                                                        scale 0.045
                                                        color_map {
                                                                [0      rgb 0.55]
                                                                [1      rgb 0.45]
                                                        }
                                                ]
                                        }
                                ]
                                [1      average
                                        pigment_map {
                                                [1      agate 
                                                        scale 0.5 
                                                        agate_turb 0.7
                                                        color_map {
                                                                [0      rgb 0]
                                                                [1      rgb 1]
                                                        }
                                                ]
                                                [1      granite 
                                                        scale 0.045
                                                        color_map {
                                                                [0      rgb 0.55]
                                                                [1      rgb 0.45]
                                                        }
                                                ]
                                        }
                                ]
                        }
                        rotate <0,0,90>
                } 
                normal { 
                        agate
                        scale 0.5  
                        agate_turb 0.7
                        normal_map {
                                [0      granite 
                                        -0.5 
                                        scale 0.015
                                ]
                                [0.2    bumps 
                                        -0.5 
                                        scale 0.005
                                ]
                                [0.5    average
                                        normal_map {
                                                [1      agate 
                                                        2 
                                                        scale 0.5 
                                                        agate_turb 0.7
                                                        cubic_wave
                                                ]
                                                [1      granite 
                                                        -0.25 
                                                        scale 0.015
                                                ]
                                        }
                                ]
                                [1      average
                                        normal_map {
                                                [1      agate 
                                                        10 
                                                        scale 0.5 
                                                        agate_turb 0.7
                                                        cubic_wave
                                                ]
                                                [1      granite 
                                                        -0.25 
                                                        scale 0.015
                                                ]
                                        }
                                ]
                        } 
                        rotate <0,0,90>
                        accuracy 0.001
                } 
                finish {			
                        ambient 0
			reflection 0.5
			diffuse 0.2
			specular 0.7
			roughness 0.003
			phong 0.5
			phong_size 10
                        brilliance 7
                }
        }
	interior {ior 1.5}
        scale 1
        Reorient_Trans (z+x*0.3, 1)    
}

sphere {
        0, 1.25
        material {T2046}
        translate <0.09,1,-0.06>
}

// right
// inspired by Jaime Vives Piqueres  A classical alarm-clock  http://www.ignorancia.org/uploads/images/despertador/wips/despertador-7b.jpg  
// paint texture influenced by Kari Kivisalo Rust & paint  http://news.povray.org/povray.binaries.scene-files/message/%3C3B141966.1B97D3E1%40x.x%3E/#%3C3B141966.1B97D3E1%40x.x%3E 
// rust texture by Nicolas Rougier  Iso-chain  http://news.povray.org/povray.binaries.scene-files/thread/%3C42bbb1a7%40news.povray.org%3E/

#declare rf = 0.4;

#declare Paint =
texture {
        pigment {color rgb <1,0.75,0.2>}
        finish {
                reflection {0.8, 0.9 metallic 1 fresnel on} 
                conserve_energy 
                diffuse 0.1
                specular 0.5 
                roughness 0.01
                metallic
                brilliance 2
        }
        normal {
                average 
                normal_map {
                        [1      bump_map {png "scratches2" interpolate 2} 
                                bump_size -0.6 
                                translate -0.5
                                scale 7 
                                Reorient_Trans (z, 1)
                        ]
                        [1      pigment_pattern {
			                granite
                                        scale 25
			                warp {turbulence 0.2 octaves 6 omega 0.8}
		                }
		                normal_map {
		                	[rf-0.1		bumps  
                                                        0
                                        ]
		                	[rf-0.075       crackle 
                                                        3 		
                                                        scale 10
		                                        warp {turbulence 0.5}
		                                        scale 0.1
                                                        turbulence 0.5 
                                                        scale 0.105
                                        ]
		                	[rf-0.02        crackle 
                                                        6
                                                        scale 10
		                                        warp {turbulence 0.5}
		                                        scale 0.1 
                                                        turbulence 0.5 
                                                        scale 0.18
                                        ]
		                }
                        ]
                }   
	}
}

#declare p_rust =
pigment {
	image_map {jpeg "rust" gamma 3.3}
	translate -0.5
	scale 10
	warp {turbulence 1 lambda 2}
}

#declare p_brass =
pigment {
	image_map {jpeg "iron06" gamma 3.3}
	translate -0.5
	scale 10
	warp {turbulence 1 lambda 2}
}

#declare rusted_metal1 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 
                                0.2 
                                scale 0.1
                        ]
			[1      cells 
                                -2 
                                warp {turbulence 1 lambda 3}
                        ]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                diffuse 1.33 
                ambient 0
        }
}

#declare rusted_metal2 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 
                                0.2 
                                scale 0.1
                        ]
			[1      cells 
                                -2 
                                warp {turbulence 1 lambda 3}
                        ]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                metallic 
                diffuse 1.05 
                ambient 0 
                reflection {0, 1 falloff 5 metallic} 
                conserve_energy
        }
}

#declare rusted_metal3 = 
texture {
        cells
        warp {turbulence 1 lambda 3}
        texture_map {
	        [0      rusted_metal1]
	        [1      rusted_metal2]
        }
}

#declare rusted_metal4 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 
                                0.4 
                                scale 0.1
                        ]
			[1      cells 
                                -2 
                                warp {turbulence 1 lambda 3}
                        ]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                diffuse 1.05 
                ambient 0
        }
}

#declare rusted_metal5 = 
texture { 
        pigment {	        
                cells
	        warp {turbulence 1 lambda 3}
	        pigment_map {
		        [0      p_rust]
		        [1      p_brass]
	        }
        }
	normal {
		average
		normal_map {
			[1      granite 
                                0.4 
                                scale 0.1
                        ]
			[1      cells 
                                -4 
                                warp {turbulence 1 lambda 3}
                        ]
		}
	}
        finish {
                specular 0.25 
                roughness 0.01 
                metallic 
                diffuse 1.05 
                ambient 0 
                reflection {0, 1 falloff 5 metallic} 
                conserve_energy
        }
}

#declare rusted_metal6 = 
texture {
        cells
        warp {turbulence 1 lambda 3}
        texture_map {
	        [0      rusted_metal4]
	        [1      rusted_metal5]
        }
        Reorient_Trans (z, 1)
}

#declare T906 =
material {
	texture {
		pigment_pattern {
			granite 
                        scale 25
			warp {turbulence 0.2 octaves 6 omega 0.8}
		}
		texture_map {
			[rf	   Paint]
			[rf	   rusted_metal6]
			[rf+0.0075 rusted_metal6]
			[rf+0.015  rusted_metal3]
			[rf+0.1    rusted_metal6]
		}
	}
	scale 0.2
	interior {ior 2.54}
}

superellipsoid { 
        <0.25, 0.25>
        rotate y*20
        translate <2.4,0.625,-0.8> 
        material {T906}
} 
